.. Projy documentation master file, created by
   sphinx-quickstart on Thu Jun 14 21:09:17 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Projy
=====

**Projy is a template-based skeleton generator**.
In one command line, you can generate project skeletons
like Python packages, LaTeX document or any file structure
composed of directories and files.

Each file is generated by a different template.
It uses the simple core templating system from Python,
nothing fancy on that part. You can easily add new templates
and new ways to collect data to insert in the created files.
As much as possible, Projy tries to be simple to use and extend.


Content
=======

.. toctree::
   :maxdepth: 2

   install
   usage
   templates
   extend


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

